# Changelog


## [1.1.0] - 2022-05-03

- Add date_filter for transaction endpoint
- Set client token property on token exchange

## [1.0.1] - 2022-01-13

- Update documentation
- Fix token setter
- Move `python-dotenv` to dev dependencies

## [1.0.0] - 2022-01-12

- Initial release
